@@ -18,7 +18,10 @@
 #' @param align the alignment of columns: a character vector consisting of
 #'   \code{'l'} (left), \code{'c'} (center) and/or \code{'r'} (right); by
 #'   default, numeric columns are right-aligned, and other columns are
-#'   left-aligned; if \code{align = NULL}, the default alignment is used
+#'   left-aligned; if \code{align = NULL}, the default alignment is used;
+#'   alternatively, if \code{length(align) == 1L}, the string will be expanded
+#'   to a vector of individual letters unless the output format is LaTeX; for
+#'   example, \code{'clc'} will be converted to \code{c('c', 'l', 'c')}
 #' @param caption the table caption
 #' @param format.args a list of arguments to be passed to \code{\link{format}()}
 #'   to format table values, e.g. \code{list(big.mark = ',')}
@@ -88,6 +91,10 @@ kable = function(
   } else 'pandoc'
   if (is.function(format)) format = format()
 
+  # expand align if applicable
+  if (format != 'latex' && !missing(align) && length(align) == 1L)
+    align = strsplit(align, '')[[1]]
+
   # create a label for bookdown if applicable
   if (!is.null(caption) && !is.na(caption)) caption = paste0(
     create_label('tab:', opts_current$get('label')), caption
@@ -329,8 +336,10 @@ kable_markdown = function(x, padding = 1, ...) {
 }
 
 kable_pandoc = function(x, caption = NULL, padding = 1, ...) {
-  tab = kable_mark(x, c(NA, '-', if (is.null(colnames(x))) '-' else NA),
-                   padding = padding, ...)
+  tab = kable_mark(
+    x, c(NA, '-', if (is_blank(colnames(x))) '-' else NA),
+    padding = padding, ...
+  )
   if (identical(caption, NA)) caption = NULL
   if (length(caption)) c(paste('Table:', caption), "", tab) else tab
 }
