@@ -18,6 +18,11 @@ assert(
   identical(kable2(m, align = 'c'), c('|   | x | y |', '|:--|:-:|:-:|', '|a  | 1 | 2 |'))
 )
 
+assert(
+  'kable() align with strings correctly',
+  identical(kable2(m, align = c('c', 'r')), kable2(m, align = 'cr'))
+)
+
 assert(
   'kable() works on character data frames',
   identical(kable2(data.frame(x = 'a')), c('|x  |', '|:--|', '|a  |'))
